diff
stringlengths 65
26.7k
| message
stringlengths 7
9.92k
|
|---|---|
diff --git a/etcdserver/server.go b/etcdserver/server.go
index <HASH>..<HASH> 100644
--- a/etcdserver/server.go
+++ b/etcdserver/server.go
@@ -941,7 +941,10 @@ func (s *EtcdServer) sendMergedSnap(merged snap.Message) {
// If the follower still fails to catch up, it is probably just too slow
// to catch up. We cannot avoid the snapshot cycle anyway.
if ok {
- time.Sleep(releaseDelayAfterSnapshot)
+ select {
+ case <-time.After(releaseDelayAfterSnapshot):
+ case <-s.done:
+ }
}
atomic.AddInt64(&s.inflightSnapshots, -1)
case <-s.done:
|
etcdserver: respect done channel when sleeping for snapshot backoff
|
diff --git a/scripts/experiments/run_srl.py b/scripts/experiments/run_srl.py
index <HASH>..<HASH> 100755
--- a/scripts/experiments/run_srl.py
+++ b/scripts/experiments/run_srl.py
@@ -119,7 +119,7 @@ class SrlExpParamsRunner(ExpParamsRunner):
self.pos_unsup_test = parser_prefix + "/dmv_conll09-sp-dev_20_False/test-parses.txt"
# Semi-supervised parser output: PHEAD column.
self.brown_semi_train = parser_prefix + "/dmv_conll09-sp-brown-train_20_True/test-parses.txt"
- self.brown_semi_test = parser_prefix + "/dmv_conll09-sp-brown-dev_10_True/test-parses.txt"
+ self.brown_semi_test = parser_prefix + "/dmv_conll09-sp-brown-dev_20_True/test-parses.txt"
# Unsupervised parser output: PHEAD column.
self.brown_unsup_train = parser_prefix + "/dmv_conll09-sp-brown-train_20_False/test-parses.txt"
self.brown_unsup_test = parser_prefix + "/dmv_conll09-sp-brown-dev_20_False/test-parses.txt"
|
Change to run_srl; grabbing brown-dev_<I>_True now, as it should.
|
diff --git a/pyhaproxy/render.py b/pyhaproxy/render.py
index <HASH>..<HASH> 100644
--- a/pyhaproxy/render.py
+++ b/pyhaproxy/render.py
@@ -165,8 +165,14 @@ backend %s
def __render_server(self, server):
server_line = ' server %s %s:%s %s\n'
+ attributes = []
+
+ #Strip out heading/trailing whitespace
+ for a in server.attributes:
+ attributes.append(a.strip())
+
return server_line % (
- server.name, server.host, server.port, ' '.join(server.attributes))
+ server.name, server.host, server.port, ' '.join(attributes))
def __render_acl(self, acl):
acl_line = ' acl %s %s\n'
|
Fix bug that would introduce whitespace to attributes with each new
render
|
diff --git a/lib/routes/apiv1.js b/lib/routes/apiv1.js
index <HASH>..<HASH> 100644
--- a/lib/routes/apiv1.js
+++ b/lib/routes/apiv1.js
@@ -331,19 +331,21 @@ function getKeysTree(req, res, next) {
return callback(err);
}
keyData.attr.rel = type;
- var sizeCallback = function(err,count){
- if(err){
- return callback(err);
- }else{
- keyData.data+=" (" + count + ")";
- callback();
- }
- };
- if(type=='list'){
- req.redisConnection.llen(keyData.fullKey,sizeCallback);
- }else if(type == 'set'){
- req.redisConnection.scard(keyData.fullKey,sizeCallback);
- }else{
+ var sizeCallback = function (err, count) {
+ if (err) {
+ return callback(err);
+ } else {
+ keyData.data += " (" + count + ")";
+ callback();
+ }
+ };
+ if (type == 'list') {
+ req.redisConnection.llen(keyData.fullKey, sizeCallback);
+ } else if (type == 'set') {
+ req.redisConnection.scard(keyData.fullKey, sizeCallback);
+ } else if (type == 'zset') {
+ req.redisConnection.zcard(keyData.fullKey, sizeCallback);
+ } else {
callback();
}
});
|
Show sorted set counts in redis tree
|
diff --git a/index.js b/index.js
index <HASH>..<HASH> 100644
--- a/index.js
+++ b/index.js
@@ -1,16 +1,5 @@
(function() {
-
- const types = {
- 'animation':'animationend',
- 'MSAnimation':'MSAnimationEnd',
- 'WebkitAnimation':'webkitAnimationEnd',
- }
-
- const event = types[
- Object.keys(types).filter(x =>
- document.body.style.hasOwnProperty(x)
- )[0]
- ]
+ const event = 'animationend'
const Actuate = animations => $ => new Promise ((resolve, reject) => {
@@ -18,7 +7,8 @@
animations : animations.split(' ')
const done = _ => {
- $.classList.remove('animated', commands[0])
+ $.classList.remove('animated')
+ $.classList.remove(commands[0])
$.removeEventListener(event, done)
commands.shift()
commands.length ? animate() : resolve($)
@@ -26,7 +16,8 @@
const animate = _ => {
$.addEventListener(event, done)
- $.classList.add('animated', commands[0])
+ $.classList.add('animated')
+ $.classList.add(commands[0])
}
$.classList.contains('animated') ?
|
fixes compatibility issues with Firefox and IE<I> (#4)
|
diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100644
--- a/setup.py
+++ b/setup.py
@@ -16,7 +16,6 @@ setup(
license='MIT',
packages=find_packages('src'),
package_dir={'': 'src'},
- package_data={'': ['VERSION']},
url='http://github.com/aeroxis/sultan',
classifiers=[
"Development Status :: 5 - Production/Stable",
|
Removed an unnecessary line in 'setup.py'
|
diff --git a/src/models/room.js b/src/models/room.js
index <HASH>..<HASH> 100644
--- a/src/models/room.js
+++ b/src/models/room.js
@@ -1525,14 +1525,6 @@ function calculateRoomName(room, userId, ignoreRoomNameEvent) {
}
let alias = room.getCanonicalAlias();
-
- if (!alias) {
- const aliases = room.getAliases();
-
- if (aliases.length) {
- alias = aliases[0];
- }
- }
if (alias) {
return alias;
}
|
room name should only take canonical alias into account
|
diff --git a/test/instrument/FMSynth.js b/test/instrument/FMSynth.js
index <HASH>..<HASH> 100644
--- a/test/instrument/FMSynth.js
+++ b/test/instrument/FMSynth.js
@@ -1,18 +1,20 @@
define(["Tone/instrument/FMSynth", "helper/Basic",
- "helper/InstrumentTests", "helper/CompareToFile"],
-function(FMSynth, Basic, InstrumentTest, CompareToFile) {
+ "helper/InstrumentTests", "helper/CompareToFile", "helper/Supports"],
+function(FMSynth, Basic, InstrumentTest, CompareToFile, Supports) {
describe("FMSynth", function(){
Basic(FMSynth);
InstrumentTest(FMSynth, "C4");
- it("matches a file", function(){
- return CompareToFile(function(){
- const synth = new FMSynth().toMaster();
- synth.triggerAttackRelease("G4", 0.1, 0.05);
- }, "fmSynth.wav");
- });
+ if (Supports.CHROME_AUDIO_RENDERING){
+ it("matches a file", function(){
+ return CompareToFile(function(){
+ const synth = new FMSynth().toMaster();
+ synth.triggerAttackRelease("G4", 0.1, 0.05);
+ }, "fmSynth.wav");
+ });
+ }
context("API", function(){
|
skipping FMSynth comparison when not on Chrome
|
diff --git a/tests/test_datatype.py b/tests/test_datatype.py
index <HASH>..<HASH> 100644
--- a/tests/test_datatype.py
+++ b/tests/test_datatype.py
@@ -29,4 +29,7 @@ class TestDatatype(TestCase):
dt = Datatype("region")
val = dt.allowed_values[u"Växjö kommun"]
self.assertTrue("wikidata" in val.dialects)
- self.assertEqual(val.dialects["wikidata"][0], u"Q500217")
+ self.assertEqual(u"Q500217", val.dialects["wikidata"].pop())
+
+ self.assertTrue("scb" in val.dialects)
+ self.assertEqual(u"0780 Växjö kommun", val.dialects["scb"].pop())
|
make test pass by testing for correct value
|
diff --git a/subscriptions/search.js b/subscriptions/search.js
index <HASH>..<HASH> 100644
--- a/subscriptions/search.js
+++ b/subscriptions/search.js
@@ -10,7 +10,7 @@ import { searchIsReady$ } from '../streams/search';
import getTrackingData from '../selectors/search';
/**
- * Pages tracking subscriptions.
+ * Search tracking subscriptions.
* @param {Function} subscribe The subscribe function.
*/
export default function search(subscribe) {
|
CON-<I>: implemented feedback from review
|
diff --git a/djangular/middleware.py b/djangular/middleware.py
index <HASH>..<HASH> 100644
--- a/djangular/middleware.py
+++ b/djangular/middleware.py
@@ -1,6 +1,7 @@
# -*- coding: utf-8 -*-
from __future__ import unicode_literals
import six
+from django import http
from django.core.handlers.wsgi import WSGIRequest
from django.core.urlresolvers import reverse
from django.utils.http import unquote
@@ -47,12 +48,6 @@ class DjangularUrlMiddleware(object):
request.environ['QUERY_STRING'] = query.urlencode()
else:
request.environ['QUERY_STRING'] = query.urlencode().encode('utf-8')
- # Reconstruct GET QueryList using WSGIRequest.GET function
- # ...
- # @cached_property
- # def GET(self):
- # raw_query_string = get_bytes_from_wsgi(self.environ, 'QUERY_STRING', '')
- # return http.QueryDict(raw_query_string, encoding=self._encoding)
- # ...
- # Since it's cached the actual function can be accessed as WSGIRequest.GET.func
- request.GET = WSGIRequest.GET.func(request)
+
+ # Reconstruct GET QueryList in the same way WSGIRequest.GET function works
+ request.GET = http.QueryDict(request.environ['QUERY_STRING'])
|
alternative request.GET building, previous version doesn't work in django <I>
|
diff --git a/salt/states/file.py b/salt/states/file.py
index <HASH>..<HASH> 100644
--- a/salt/states/file.py
+++ b/salt/states/file.py
@@ -97,9 +97,19 @@ In this example ``foo.conf`` in the ``dev`` environment will be used instead.
.. warning::
- When using a mode that includes a leading zero you must wrap the
- value in single quotes. If the value is not wrapped in quotes it
- will be read by YAML as an integer and evaluated as an octal.
+ When using a mode that includes a leading zero you must wrap the
+ value in single quotes. If the value is not wrapped in quotes it
+ will be read by YAML as an integer and evaluated as an octal.
+
+The ``names`` parameter, which is part of the state compiler, can be used to
+expand the contents of a single state declaration into multiple, single state
+declarations. Each item in the ``names`` list receives its own individual state
+``name`` and is converted into its own low-data structure. This is a convenient
+way to manage several files with similar attributes.
+
+There is more documentation about this feature in the
+:ref:`Names declaration<names-declaration>` section of the
+ :ref:`Highstate docs<states-highstate>`.
Special files can be managed via the ``mknod`` function. This function will
create and enforce the permissions on a special file. The function supports the
|
Add "names" option to file state docs: point users to highstate doc examples (#<I>)
* Add "names" option to file state docs: point users to highstate doc examples
Fixes #<I>
* Grammar fix
|
diff --git a/splinter/driver/webdriver/__init__.py b/splinter/driver/webdriver/__init__.py
index <HASH>..<HASH> 100644
--- a/splinter/driver/webdriver/__init__.py
+++ b/splinter/driver/webdriver/__init__.py
@@ -131,9 +131,6 @@ class BaseWebDriver(DriverAPI):
def is_element_not_present_by_id(self, id):
return self.is_element_not_present(self.find_by_id, id)
-
- def switch_to_frame(self, id):
- self.driver.switch_to_frame(id)
@contextmanager
def get_iframe(self, id):
|
removed swtich_to_frame method, as it is deprecated.
|
diff --git a/Nameless/Modules/Assets/Asset.php b/Nameless/Modules/Assets/Asset.php
index <HASH>..<HASH> 100644
--- a/Nameless/Modules/Assets/Asset.php
+++ b/Nameless/Modules/Assets/Asset.php
@@ -186,7 +186,7 @@ class Asset
$urls_old = array();
$urls_new = array();
- preg_match_all('#url\((.*)\)#im', $asset_text, $urls_old);
+ preg_match_all('#url\([\'"]?([^/\'"][^\'"]*)[\'"]?\)#im', $asset_text, $urls_old);
foreach ($urls_old[1] as $url)
{
|
Bugfix: excluded absolute pathes from CSS pathreplacement
|
diff --git a/lib/db_charmer/rails3/active_record/relation/connection_routing.rb b/lib/db_charmer/rails3/active_record/relation/connection_routing.rb
index <HASH>..<HASH> 100644
--- a/lib/db_charmer/rails3/active_record/relation/connection_routing.rb
+++ b/lib/db_charmer/rails3/active_record/relation/connection_routing.rb
@@ -59,12 +59,15 @@ module DbCharmer
end
# Connection switching (changes the default relation connection)
- def on_db(con)
- old_connection = db_charmer_connection
- self.db_charmer_connection = con
- clone
- ensure
- self.db_charmer_connection = old_connection
+ def on_db(con, &block)
+ if block_given?
+ @klass.on_db(con, &block)
+ else
+ clone.tap do |result|
+ result.db_charmer_connection = con
+ result.db_charmer_connection_is_forced = true
+ end
+ end
end
# Make sure we get the right connection here
|
Support block on_db calls on relations + allow forcing connections on relation
|
diff --git a/app/views/dashboard/components/edit.blade.php b/app/views/dashboard/components/edit.blade.php
index <HASH>..<HASH> 100644
--- a/app/views/dashboard/components/edit.blade.php
+++ b/app/views/dashboard/components/edit.blade.php
@@ -43,7 +43,7 @@
</div>
@if($groups->count() > 0)
<div class='form-group'>
- <label>Group</label>
+ <label>{{ trans('forms.components.group') }}</label>
<select name='component[group_id]' class='form-control'>
<option {{ $component->group_id === null ? "selected" : null }}></option>
@foreach($groups as $group)
|
Remove remaining plain English from edit.blade.php view
|
diff --git a/smartcard/pcsc/PCSCCardConnection.py b/smartcard/pcsc/PCSCCardConnection.py
index <HASH>..<HASH> 100644
--- a/smartcard/pcsc/PCSCCardConnection.py
+++ b/smartcard/pcsc/PCSCCardConnection.py
@@ -68,6 +68,7 @@ class PCSCCardConnection( CardConnection ):
"""
CardConnection.__init__( self, reader )
self.hcard = None
+ self.dwActiveProtocol = SCARD_PROTOCOL_T0 | SCARD_PROTOCOL_T1
hresult, self.hcontext = SCardEstablishContext( SCARD_SCOPE_USER )
if hresult!=0:
raise CardConnectionException( 'Failed to establish context : ' + SCardGetErrorMessage(hresult) )
@@ -124,6 +125,10 @@ class PCSCCardConnection( CardConnection ):
raise CardConnectionException( 'Failed to get status: ' + SCardGetErrorMessage(hresult) )
return atr
+ def getProtocol( self ):
+ """Return the protocol negociated during connect()."""
+ return self.dwActiveProtocol
+
def doTransmit( self, bytes, protocol=None ):
"""Transmit an apdu to the card and return response apdu.
|
implement getProtocol() to return the protocol negociated during connect()
|
diff --git a/examples/mvvmfx-fx-root-example/src/main/java/de/saxsys/jfx/mvvmfx/fx_root_example/LabeledTextFieldViewModel.java b/examples/mvvmfx-fx-root-example/src/main/java/de/saxsys/jfx/mvvmfx/fx_root_example/LabeledTextFieldViewModel.java
index <HASH>..<HASH> 100644
--- a/examples/mvvmfx-fx-root-example/src/main/java/de/saxsys/jfx/mvvmfx/fx_root_example/LabeledTextFieldViewModel.java
+++ b/examples/mvvmfx-fx-root-example/src/main/java/de/saxsys/jfx/mvvmfx/fx_root_example/LabeledTextFieldViewModel.java
@@ -23,7 +23,7 @@ public class LabeledTextFieldViewModel implements ViewModel {
@Override
public Boolean call() throws Exception {
final String text = inputText.get();
- return text != null && text.isEmpty();
+ return text == null || text.isEmpty();
}
}, inputText));
}
|
Fix wrong boolean binding in fx-root example
|
diff --git a/azurerm/data_source_redis_cache.go b/azurerm/data_source_redis_cache.go
index <HASH>..<HASH> 100644
--- a/azurerm/data_source_redis_cache.go
+++ b/azurerm/data_source_redis_cache.go
@@ -251,6 +251,8 @@ func dataSourceArmRedisCacheRead(d *schema.ResourceData, meta interface{}) error
if err = d.Set("patch_schedule", patchSchedule); err != nil {
return fmt.Errorf("Error setting `patch_schedule`: %+v", err)
}
+ } else {
+ d.Set("patch_schedule", []interface{}{})
}
keys, err := client.ListKeys(ctx, resourceGroup, name)
|
Set `patch_schedule` to empty list if no schedules present - allows
outputs to be used for this item without error, even when there are no schedules.
|
diff --git a/test/plugin-apply-test.js b/test/plugin-apply-test.js
index <HASH>..<HASH> 100644
--- a/test/plugin-apply-test.js
+++ b/test/plugin-apply-test.js
@@ -238,8 +238,9 @@ test.cb("emit inline asset", t => {
io.read(path.join(OUTPUT_PATH, "inline-asset.html")).then(output => {
io.read(sourceFile).then(source => {
- const sourceWithoutNewlines = source.replace(/\r?\n|\r/g, "");
- t.true(output.includes(sourceWithoutNewlines));
+ // HACK: Trim source as output differs between webpack versions
+ const trimmedSource = source.replace(/;\r?\n|\r/g, "");
+ t.true(output.includes(trimmedSource));
t.end();
});
});
|
Trim source as output differs between webpack versions
|
diff --git a/lib/components/viewers/route-details.js b/lib/components/viewers/route-details.js
index <HASH>..<HASH> 100644
--- a/lib/components/viewers/route-details.js
+++ b/lib/components/viewers/route-details.js
@@ -182,6 +182,7 @@ class RouteDetails extends Component {
Object.entries(patterns)
.map((pattern) => {
return {
+ geometryLength: pattern[1].geometry?.length,
headsign: extractHeadsignFromPattern(pattern[1]),
id: pattern[0]
}
@@ -190,7 +191,14 @@ class RouteDetails extends Component {
// with a specific headsign is the accepted one. TODO: is this good behavior?
.reduce((prev, cur) => {
const amended = prev
- if (!prev.find(h => h.headsign === cur.headsign)) {
+ const alreadyExistingIndex = prev.findIndex(h => h.headsign === cur.headsign)
+ // If the item we're replacing has less geometry, replace it!
+ if (alreadyExistingIndex >= 0) {
+ // Only replace if new pattern has greater geometry
+ if (amended[alreadyExistingIndex].geometryLength < cur.geometryLength) {
+ amended[alreadyExistingIndex] = cur
+ }
+ } else {
amended.push(cur)
}
return amended
|
improvement(route-details): resolve duplicate headsigns based on geometry length
|
diff --git a/structr-core/src/main/java/org/structr/core/entity/SchemaNode.java b/structr-core/src/main/java/org/structr/core/entity/SchemaNode.java
index <HASH>..<HASH> 100644
--- a/structr-core/src/main/java/org/structr/core/entity/SchemaNode.java
+++ b/structr-core/src/main/java/org/structr/core/entity/SchemaNode.java
@@ -294,6 +294,13 @@ public class SchemaNode extends AbstractSchemaNode {
return;
}
+ // migrate RemoteDocument
+ if (_extendsClass.equals("org.structr.web.entity.RemoteDocument")) {
+
+ setProperty(extendsClass, "org.structr.feed.entity.RemoteDocument");
+ return;
+ }
+
// migrate Person
if (_extendsClass.equals("org.structr.core.entity.Person")) {
|
Enhancement: Adds migration code for RemoteDocument class.
|
diff --git a/lib/daemon/index.js b/lib/daemon/index.js
index <HASH>..<HASH> 100644
--- a/lib/daemon/index.js
+++ b/lib/daemon/index.js
@@ -8,7 +8,7 @@ function Daemon(conf) {
Daemon.prototype.initialize = function(conf) {
if (conf.verbose) log.setVerbose(conf.verbose);
log.debug('gearslothd', 'Config parsed:\n',
- util.inspect(conf, { depth: null }));
+ util.inspect(conf, { depth: 3 }));
if (conf.injector) this.add('./injector', conf);
if (conf.runner) this.add('./runner', conf);
|
Limit recursion depth to avoid huge object dumps
|
diff --git a/src/DebugBar/Storage/FileStorage.php b/src/DebugBar/Storage/FileStorage.php
index <HASH>..<HASH> 100644
--- a/src/DebugBar/Storage/FileStorage.php
+++ b/src/DebugBar/Storage/FileStorage.php
@@ -77,7 +77,7 @@ class FileStorage implements StorageInterface
$data = $this->get($file['id']);
$meta = $data['__meta'];
unset($data);
- if (array_keys(array_intersect($meta, $filters)) == array_keys($filters)) {
+ if ($this->filter($meta, $filters)) {
$results[] = $meta;
}
if(count($results) >= ($max + $offset)){
@@ -87,6 +87,15 @@ class FileStorage implements StorageInterface
return array_slice($results, $offset, $max);
}
+
+ protected function filter($meta, $filters){
+ foreach($filters as $key => $value){
+ if(fnmatch ($value, $meta[$key]) === false){
+ return false;
+ }
+ }
+ return true;
+ }
/**
* {@inheritDoc}
|
Improve filtering
Make filter work with multiple keys and wildcard search, eg. user/* or ip <I>.*
|
diff --git a/oneapi/client.php b/oneapi/client.php
index <HASH>..<HASH> 100644
--- a/oneapi/client.php
+++ b/oneapi/client.php
@@ -72,6 +72,12 @@ class AbstractOneApiClient {
$this->throwException = true;
}
+ public function setAPIurl($baseUrl=NULL) {
+ $this->baseUrl = $baseUrl ? $baseUrl : self::$DEFAULT_BASE_URL;
+ if ($this->baseUrl[strlen($this->baseUrl) - 1] != '/')
+ $this->baseUrl .= '/';
+ }
+
public function login() {
$restPath = '/1/customerProfile/login';
|
Added client->setAPIurl() method to library
|
diff --git a/core/src/main/java/org/springframework/security/jackson2/SecurityJackson2Modules.java b/core/src/main/java/org/springframework/security/jackson2/SecurityJackson2Modules.java
index <HASH>..<HASH> 100644
--- a/core/src/main/java/org/springframework/security/jackson2/SecurityJackson2Modules.java
+++ b/core/src/main/java/org/springframework/security/jackson2/SecurityJackson2Modules.java
@@ -1,5 +1,5 @@
/*
- * Copyright 2015-2018 the original author or authors.
+ * Copyright 2015-2019 the original author or authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
@@ -225,7 +225,7 @@ public final class SecurityJackson2Modules {
JavaType result = delegate.typeFromId(context, id);
String className = result.getRawClass().getName();
if (isWhitelisted(className)) {
- return delegate.typeFromId(context, id);
+ return result;
}
boolean isExplicitMixin = config.findMixInClassFor(result.getRawClass()) != null;
if (isExplicitMixin) {
|
Resolve JavaType only once for whitelisted class
|
diff --git a/lib/fuzzystringmatch.rb b/lib/fuzzystringmatch.rb
index <HASH>..<HASH> 100644
--- a/lib/fuzzystringmatch.rb
+++ b/lib/fuzzystringmatch.rb
@@ -20,7 +20,11 @@ begin
if RUBY_PLATFORM == "java"
STDERR.puts "fuzzy-string-match Warning: native version is disabled on java platform. falled back to pure ruby version..."
else
- require 'fuzzystringmatch/inline'
+ begin
+ require 'fuzzystringmatch/inline'
+ rescue CompilationError
+ STDERR.puts "fuzzy-string-match Warning: fallback into pure version, because compile failed."
+ end
end
rescue LoadError
end
diff --git a/test/fallback_pure_spec.rb b/test/fallback_pure_spec.rb
index <HASH>..<HASH> 100644
--- a/test/fallback_pure_spec.rb
+++ b/test/fallback_pure_spec.rb
@@ -28,6 +28,8 @@ require 'inline'
describe Inline, "when c compile failed, fall back into pure " do
it "should" do
pending ("because JRuby always in pure mode.") if (RUBY_PLATFORM == "java")
- lambda { require 'fuzzystringmatch' }.should raise_error( CompilationError )
+ lambda { require 'fuzzystringmatch' }.should_not raise_error()
+
+ FuzzyStringMatch::JaroWinkler.create( :native ).pure?( ).should be_true
end
end
|
Commit in incomplete code.
Must make `ballback code`.
|
diff --git a/Core/Search/Solr/Query/Content/CriterionVisitor/Tags.php b/Core/Search/Solr/Query/Content/CriterionVisitor/Tags.php
index <HASH>..<HASH> 100644
--- a/Core/Search/Solr/Query/Content/CriterionVisitor/Tags.php
+++ b/Core/Search/Solr/Query/Content/CriterionVisitor/Tags.php
@@ -18,7 +18,7 @@ abstract class Tags extends CriterionVisitor
/**
* For tag-queries which aren't field-specific.
- *
+ *
* @var \eZ\Publish\SPI\Persistence\Content\Type\Handler
*/
protected $contentTypeHandler;
@@ -78,7 +78,7 @@ abstract class Tags extends CriterionVisitor
continue;
}
- if ($fieldDefinition['field_type_identifier'] != 'eztags') {
+ if ($fieldDefinition['field_type_identifier'] != $this->fieldTypeIdentifier) {
continue;
}
|
Use already available field type identified in solr criterion visitors
|
diff --git a/modin/pandas/test/utils.py b/modin/pandas/test/utils.py
index <HASH>..<HASH> 100644
--- a/modin/pandas/test/utils.py
+++ b/modin/pandas/test/utils.py
@@ -11,6 +11,7 @@
# ANY KIND, either express or implied. See the License for the specific language
# governing permissions and limitations under the License.
+import re
import pytest
import numpy as np
import math
@@ -1101,10 +1102,17 @@ def check_file_leaks(func):
try:
fstart.remove(item)
except ValueError:
- # ignore files in /proc/, as they have nothing to do with
- # modin reading any data (and this is what we care about)
- if not item[0].startswith("/proc/"):
- leaks.append(item)
+ # Ignore files in /proc/, as they have nothing to do with
+ # modin reading any data (and this is what we care about).
+ if item[0].startswith("/proc/"):
+ continue
+ # Ignore files in /tmp/ray/session_*/logs (ray session logs)
+ # because Ray intends to keep these logs open even after
+ # work has been done.
+ if re.search(r"/tmp/ray/session_.*/logs", item[0]):
+ continue
+ leaks.append(item)
+
assert (
not leaks
), f"Unexpected open handles left for: {', '.join(item[0] for item in leaks)}"
|
FIX-#<I>: Ignore files from /private/tmp/ray/ when detecting file leaks (#<I>)
|
diff --git a/mechanicalsoup/form.py b/mechanicalsoup/form.py
index <HASH>..<HASH> 100644
--- a/mechanicalsoup/form.py
+++ b/mechanicalsoup/form.py
@@ -273,10 +273,10 @@ class Form(object):
self.form.append(control)
return control
- def choose_submit(self, el):
+ def choose_submit(self, submit):
"""Selects the input (or button) element to use for form submission.
- :param el: The bs4.element.Tag (or just its *name*-attribute) that
+ :param submit: The bs4.element.Tag (or just its *name*-attribute) that
identifies the submit element to use.
To simulate a normal web browser, only one submit element must be
@@ -298,10 +298,10 @@ class Form(object):
found = False
inps = self.form.select('input[type="submit"], button[type="submit"]')
for inp in inps:
- if inp == el or inp['name'] == el:
+ if inp == submit or inp['name'] == submit:
if found:
raise LinkNotFoundError(
- "Multiple submit elements match: {0}".format(el)
+ "Multiple submit elements match: {0}".format(submit)
)
found = True
continue
@@ -310,7 +310,7 @@ class Form(object):
if not found:
raise LinkNotFoundError(
- "Specified submit element not found: {0}".format(el)
+ "Specified submit element not found: {0}".format(submit)
)
def print_summary(self):
|
form.py: rename argument of choose_submit
The name `el` was not sufficiently descriptive or clear. Instead,
we name it `submit` because it is the Tag of the submit element
or its name-attribute.
|
diff --git a/scdl/scdl.py b/scdl/scdl.py
index <HASH>..<HASH> 100755
--- a/scdl/scdl.py
+++ b/scdl/scdl.py
@@ -491,7 +491,7 @@ def download_track(track, playlist_name=None, playlist_file=None):
logger.info('{0} already Downloaded'.format(title))
return
else:
- logger.error('Music already exists ! (exiting)')
+ logger.error('Music already exists ! (use -c to continue)')
sys.exit(0)
logger.info('{0} Downloaded.\n'.format(filename))
|
More meaningfull message when already music exits
|
diff --git a/bin/test.js b/bin/test.js
index <HASH>..<HASH> 100644
--- a/bin/test.js
+++ b/bin/test.js
@@ -46,7 +46,8 @@ test.config = {
name: 'test',
description: 'Runs test suite',
options: [
- ['u', 'updateSnapshot', 'Update snapshots'],
+ ['', 'coverage', 'Indicates that test coverage information should be collected and reported in the output.'],
+ ['u', 'updateSnapshot', 'Use this flag to re-record snapshots.'],
['', 'verbose', 'Display individual test results with the test suite hierarchy']
]
};
|
KSBWI-<I> added --coverage param
|
diff --git a/sqlparse/keywords.py b/sqlparse/keywords.py
index <HASH>..<HASH> 100644
--- a/sqlparse/keywords.py
+++ b/sqlparse/keywords.py
@@ -46,7 +46,11 @@ SQL_REGEX = {
(r'(CASE|IN|VALUES|USING)\b', tokens.Keyword),
(r'(@|##|#)[A-Z]\w+', tokens.Name),
- (r'[A-Z]\w*(?=\.)', tokens.Name), # see issue39
+
+ # see issue #39
+ # Spaces around period `schema . name` are valid identifier
+ # TODO: Spaces before period not implemented
+ (r'[A-Z]\w*(?=\s*\.)', tokens.Name), # 'Name' .
(r'(?<=\.)[A-Z]\w*', tokens.Name), # .'Name'
(r'[A-Z]\w*(?=\()', tokens.Name), # side effect: change kw to func
|
Rewrite regex to allow spaces between `name` and `.`
|
diff --git a/infra/azure/vm/helper.js b/infra/azure/vm/helper.js
index <HASH>..<HASH> 100644
--- a/infra/azure/vm/helper.js
+++ b/infra/azure/vm/helper.js
@@ -101,10 +101,30 @@ const helper = {
if (opts.vmSize.resourceDiskSizeInMB) record.resourceDiskSizeInMB = opts.vmSize.resourceDiskSizeInMB;
if (opts.vmSize.memoryInMB) record.memoryInMB = opts.vmSize.memoryInMB;
if (opts.vmSize.maxDataDiskCount) record.maxDataDiskCount = opts.vmSize.maxDataDiskCount;
+
+ record.label = record.name + ` / CPU: ${record.numberOfCores}`;
+ let memory = record.memoryInMB;
+ if(memory > 1024){
+ memory = memory / 1024;
+ record.label += ` / RAM: ${memory}GB`;
+ }
+ else{
+ record.label += ` / RAM: ${memory}MB`;
+ }
+
+ let hd = record.resourceDiskSizeInMB;
+ if(hd > 1024){
+ hd = hd / 1024;
+ record.label += ` / HD: ${hd}GB`;
+ }
+ else{
+ record.label += ` / HD: ${hd}MB`;
+ }
}
return record;
},
+
buildRunCommmand: function(opts){
let record ={};
|
added label property to vmSize normalized response
|
diff --git a/src/streamify.js b/src/streamify.js
index <HASH>..<HASH> 100644
--- a/src/streamify.js
+++ b/src/streamify.js
@@ -77,7 +77,7 @@ function streamify (data, options) {
}
if (check.positive(options.space)) {
- space = Array(options.space).join(' ');
+ space = Array(options.space + 1).join(' ');
} else {
space = options.space;
}
|
Fix off-by-one error.
|
diff --git a/handler/src/main/java/io/netty/handler/ssl/SslHandler.java b/handler/src/main/java/io/netty/handler/ssl/SslHandler.java
index <HASH>..<HASH> 100644
--- a/handler/src/main/java/io/netty/handler/ssl/SslHandler.java
+++ b/handler/src/main/java/io/netty/handler/ssl/SslHandler.java
@@ -1527,6 +1527,7 @@ public class SslHandler extends ByteToMessageDecoder implements ChannelOutboundH
try {
// Release all resources such as internal buffers that SSLEngine
// is managing.
+ outboundClosed = true;
engine.closeOutbound();
if (closeInbound) {
@@ -1574,6 +1575,9 @@ public class SslHandler extends ByteToMessageDecoder implements ChannelOutboundH
private void closeOutboundAndChannel(
final ChannelHandlerContext ctx, final ChannelPromise promise, boolean disconnect) throws Exception {
+ outboundClosed = true;
+ engine.closeOutbound();
+
if (!ctx.channel().isActive()) {
if (disconnect) {
ctx.disconnect(promise);
@@ -1583,9 +1587,6 @@ public class SslHandler extends ByteToMessageDecoder implements ChannelOutboundH
return;
}
- outboundClosed = true;
- engine.closeOutbound();
-
ChannelPromise closeNotifyPromise = ctx.newPromise();
try {
flush(ctx, closeNotifyPromise);
|
Close SSLEngine when connection fails.
Motivation:
When using the JdkSslEngine, the ALPN class is used keep a reference
to the engine. In the event that the TCP connection fails, the
SSLEngine is not removed from the map, creating a memory leak.
Modification:
Always close the SSLEngine regardless of if the channel became
active. Also, record the SSLEngine was closed in all places.
Result:
Fixes: <URL>
|
diff --git a/jsonfield/__init__.py b/jsonfield/__init__.py
index <HASH>..<HASH> 100644
--- a/jsonfield/__init__.py
+++ b/jsonfield/__init__.py
@@ -0,0 +1 @@
+from fields import JSONField
\ No newline at end of file
|
Some existing apps expect this to be present.
For example Gargoyle does this "from jsonfield import JSONField", expecting this (older) version of django-jsonfield to be present:
<URL>
|
diff --git a/adafruit_platformdetect/board.py b/adafruit_platformdetect/board.py
index <HASH>..<HASH> 100644
--- a/adafruit_platformdetect/board.py
+++ b/adafruit_platformdetect/board.py
@@ -72,7 +72,7 @@ class Board:
board_id = None
if chip_id == chips.H3:
- board_id = self._armbian_id()
+ board_id = self._armbian_id() or self._allwinner_variants_id()
elif chip_id == chips.BCM2XXX:
board_id = self._pi_id()
elif chip_id == chips.AM33XX:
|
Fix: Added requested support for allwinner variants
|
diff --git a/src/main/java/com/rackspace/cloud/api/docs/CalabashHelper.java b/src/main/java/com/rackspace/cloud/api/docs/CalabashHelper.java
index <HASH>..<HASH> 100644
--- a/src/main/java/com/rackspace/cloud/api/docs/CalabashHelper.java
+++ b/src/main/java/com/rackspace/cloud/api/docs/CalabashHelper.java
@@ -51,9 +51,9 @@ public class CalabashHelper {
strBuff
.append("<c:param name=\"")
- .append(entry.getKey())
+ .append(escapeXmlAttribute(entry.getKey()))
.append("\" namespace=\"\" value=\"")
- .append(rawValue)
+ .append(escapeXmlAttribute(rawValue))
.append("\"/>");
}
}
@@ -74,6 +74,18 @@ public class CalabashHelper {
return sources.get(0);
}
+ private static String escapeXmlAttribute(String value) {
+ if (value == null) {
+ return "";
+ }
+
+ return value
+ .replace("&", "&")
+ .replace("\"", """)
+ .replace("'", "'")
+ .replace("%", "%");
+ }
+
/**
* Creates a {@link Source} for use in a Calabash pipeline.
*
|
Make sure to escape parameter values since they are pass as XML attributes
|
diff --git a/influxdb/influxdb08/dataframe_client.py b/influxdb/influxdb08/dataframe_client.py
index <HASH>..<HASH> 100644
--- a/influxdb/influxdb08/dataframe_client.py
+++ b/influxdb/influxdb08/dataframe_client.py
@@ -96,9 +96,11 @@ class DataFrameClient(InfluxDBClient):
elif len(result) == 1:
return self._to_dataframe(result[0], time_precision)
else:
- return {time_series['name']: self._to_dataframe(time_series,
- time_precision)
- for time_series in result}
+ ret = {}
+ for time_series in result:
+ ret[time_series['name']] = self._to_dataframe(time_series,
+ time_precision)
+ return ret
def _to_dataframe(self, json_result, time_precision):
dataframe = pd.DataFrame(data=json_result['points'],
|
Remove dict comprehension for py<I>
|
diff --git a/example/ssd/benchmark_score.py b/example/ssd/benchmark_score.py
index <HASH>..<HASH> 100644
--- a/example/ssd/benchmark_score.py
+++ b/example/ssd/benchmark_score.py
@@ -29,7 +29,7 @@ from symbol.symbol_factory import get_symbol_train
from symbol import symbol_builder
-parser = argparse.ArgumentParser(description='MxNet SSD benchmark')
+parser = argparse.ArgumentParser(description='MXNet SSD benchmark')
parser.add_argument('--network', '-n', type=str, default='vgg16_reduced')
parser.add_argument('--batch_size', '-b', type=int, default=0)
parser.add_argument('--shape', '-w', type=int, default=300)
|
Update benchmark_score.py (#<I>)
|
diff --git a/filesystem/FileNameFilter.php b/filesystem/FileNameFilter.php
index <HASH>..<HASH> 100644
--- a/filesystem/FileNameFilter.php
+++ b/filesystem/FileNameFilter.php
@@ -97,7 +97,7 @@ class FileNameFilter {
* @return Transliterator|NULL
*/
function getTransliterator() {
- if(!$this->transliterator === null && self::$default_use_transliterator) {
+ if($this->transliterator === null && self::$default_use_transliterator) {
$this->transliterator = Object::create('Transliterator');
}
return $this->transliterator;
|
BUGFIX Fixed double negation of transliterator checks in FileNameFilter, which meant it wasn't used by default when filtering SiteTree->URLSegment
|
diff --git a/packages/core/src/batch/BatchRenderer.js b/packages/core/src/batch/BatchRenderer.js
index <HASH>..<HASH> 100644
--- a/packages/core/src/batch/BatchRenderer.js
+++ b/packages/core/src/batch/BatchRenderer.js
@@ -310,7 +310,7 @@ export default class BatchRenderer extends ObjectRenderer
this.packGeometry(sprite, float32View, uint32View, indexBuffer, index, indexCount);// argb, nextTexture._id, float32View, uint32View, indexBuffer, index, indexCount);
// push a graphics..
- index += (sprite.vertexData.length / 2) * 6;
+ index += (sprite.vertexData.length / 2) * this.vertSize;
indexCount += sprite.indices.length;
}
@@ -390,7 +390,7 @@ export default class BatchRenderer extends ObjectRenderer
packGeometry(element, float32View, uint32View, indexBuffer, index, indexCount)
{
- const p = index / 6;// float32View.length / 6 / 2;
+ const p = index / this.vertSize;// float32View.length / 6 / 2;
const uvs = element.uvs;
const indicies = element.indices;// geometry.getIndex().data;// indicies;
const vertexData = element.vertexData;
|
Fixes instances of hard-coded vertSize in BatchRenderer (#<I>)
|
diff --git a/render.js b/render.js
index <HASH>..<HASH> 100755
--- a/render.js
+++ b/render.js
@@ -9,8 +9,9 @@ var React = require('react');
var ReactDOMServer = require('react-dom/server');
var argv = require('yargs')
- .usage('Usage: $0 [--port NUM]')
+ .usage('Usage: $0 [--port NUM] [--host ADDRESS]')
.describe('port', 'The port to listen to')
+ .describe('host', 'The host address to bind to')
.describe('debug', 'Print stack traces on error').alias('debug', 'd')
.describe('watch', 'Watch the source for changes and reload')
.describe('whitelist', 'Whitelist a root directory where the javascript files can be')
@@ -91,7 +92,7 @@ app.use(function errorHandler(err, request, response, next) {
response.status(500).send(argv.debug ? err.stack : "An error occurred during rendering");
});
-var server = app.listen(argv.port || 63578, 'localhost', function() {
+var server = app.listen(argv.port || 63578, argv.host || 'localhost', function() {
console.log('Started server at http://%s:%s', server.address().address, server.address().port);
});
|
Allow changing the bind address of the server.
|
diff --git a/api/opentrons/containers/placeable.py b/api/opentrons/containers/placeable.py
index <HASH>..<HASH> 100644
--- a/api/opentrons/containers/placeable.py
+++ b/api/opentrons/containers/placeable.py
@@ -622,6 +622,8 @@ class Container(Placeable):
new_wells = WellSeries(self.get_children_list())
elif len(args) > 1:
new_wells = WellSeries([self.well(n) for n in args])
+ elif 'x' in kwargs or 'y' in kwargs:
+ new_wells = self._parse_wells_x_y(*args, **kwargs)
else:
new_wells = self._parse_wells_to_and_length(*args, **kwargs)
@@ -674,6 +676,11 @@ class Container(Placeable):
return WellSeries(
wrapped_wells[start + total_kids::step][:length])
+ def _parse_wells_x_y(self, *args, **kwargs):
+ x = kwargs.get('x', None)
+ y = kwargs.get('y', None)
+
+
class WellSeries(Container):
"""
|
adds placeholder for xy placeable method
|
diff --git a/npm.js b/npm.js
index <HASH>..<HASH> 100644
--- a/npm.js
+++ b/npm.js
@@ -10,6 +10,14 @@ var debug = require('debug')('licenses::npm');
*/
module.exports = require('./parser').extend({
/**
+ * The name of this parser.
+ *
+ * @type {String}
+ * @private
+ */
+ name: 'npm',
+
+ /**
* Parse the npm license information from the package.
*
* @param {Object} data The package.json or npm package contents.
@@ -81,15 +89,10 @@ module.exports = require('./parser').extend({
return parser.license(item);
}).filter(Boolean)
);
- }
-
- if ('object' === typeof data.licenses && Object.keys(data.licenses).length) {
+ } else if ('object' === typeof data.licenses) {
Array.prototype.push.apply(
matches,
- Object.keys(data.licenses).map(function map(key) {
- if (!parser.license(data.licenses[key])) return undefined;
- return data.licenses[key];
- }).filter(Boolean)
+ parser.license(data)
);
}
|
[fix] Correctly parse licenses objects from the package.json
|
diff --git a/lib/consumers/email_consumer.rb b/lib/consumers/email_consumer.rb
index <HASH>..<HASH> 100644
--- a/lib/consumers/email_consumer.rb
+++ b/lib/consumers/email_consumer.rb
@@ -8,7 +8,7 @@ module Chatterbox
end
def process
- Chatterbox.logger.debug { "Sending notification #{notice.inspect}"}
+ Chatterbox.logger.debug { "Mailing notification #{notice[:summary]}"}
Mailer.deliver_exception_notification(notice)
end
|
Log the summary, not the whole notice
|
diff --git a/lib/puppet/vendor/semantic/lib/semantic/dependency/module_release.rb b/lib/puppet/vendor/semantic/lib/semantic/dependency/module_release.rb
index <HASH>..<HASH> 100644
--- a/lib/puppet/vendor/semantic/lib/semantic/dependency/module_release.rb
+++ b/lib/puppet/vendor/semantic/lib/semantic/dependency/module_release.rb
@@ -32,6 +32,20 @@ module Semantic
end
def <=>(oth)
+ # Note that prior to ruby 2.3.0, if a <=> method threw an exception, ruby
+ # would silently rescue the exception and return nil from <=> (which causes
+ # the derived == comparison to return false). Starting in ruby 2.3.0, this
+ # behavior changed and the exception is actually thrown. Some comments at:
+ # https://bugs.ruby-lang.org/issues/7688
+ #
+ # So simply return nil here if any of the needed fields are not available,
+ # since attempting to access a missing field is one way to force an exception.
+ # This doesn't help if the <=> use below throws an exception, but it
+ # handles the most typical cause.
+ return nil if !oth.respond_to?(:priority) ||
+ !oth.respond_to?(:name) ||
+ !oth.respond_to?(:version)
+
our_key = [ priority, name, version ]
their_key = [ oth.priority, oth.name, oth.version ]
|
(PUP-<I>) Handle unexpected compares gracefully
This commit is part of adding ruby <I> support to puppet.
Note that prior to ruby <I>, if a <=> method threw an exception, ruby
would silently rescue the exception and return nil from <=> (which causes
the derived == comparison to return false). Starting in ruby <I>, this
behavior changed and the exception is actually thrown. Some comments at:
<URL>
|
diff --git a/TYPO3.Flow/Classes/Security/Controller/LoginController.php b/TYPO3.Flow/Classes/Security/Controller/LoginController.php
index <HASH>..<HASH> 100755
--- a/TYPO3.Flow/Classes/Security/Controller/LoginController.php
+++ b/TYPO3.Flow/Classes/Security/Controller/LoginController.php
@@ -36,8 +36,6 @@ namespace F3\FLOW3\Security\Controller;
* @version $Id: $
* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser Public License, version 3 or later
*/
-use F3\FLOW3\MVC\Controller;
-
class LoginController extends \F3\FLOW3\MVC\Controller\ActionController {
/**
|
FLOW3:
* removed useless use uselessly added by PDT
* fixed copy-n-paste error in TYPO3CR Routes.yaml
Original-Commit-Hash: 6cc<I>b<I>cbb8e<I>f1ca<I>a<I>b<I>e2d
|
diff --git a/estnltk/taggers/syntax/conll_morph_tagger.py b/estnltk/taggers/syntax/conll_morph_tagger.py
index <HASH>..<HASH> 100644
--- a/estnltk/taggers/syntax/conll_morph_tagger.py
+++ b/estnltk/taggers/syntax/conll_morph_tagger.py
@@ -49,8 +49,7 @@ def get_values(id, text):
text.analyse('syntax_preprocessing')
res1 = export_CG3(text)
vislcgRulesDir = abs_path('taggers/syntax/files')
- vislcg_path = '/usr/bin/vislcg3'
- pipeline2 = VISLCG3Pipeline(rules_dir=vislcgRulesDir, vislcg_cmd=vislcg_path)
+ pipeline2 = VISLCG3Pipeline(rules_dir=vislcgRulesDir)
results2 = pipeline2.process_lines(res1)
for j, word in enumerate(list(filter(None, convert_cg3_to_conll(results2.split('\n'))))):
if word != '':
|
Bugfix in conll_morph_tagger: removed hardcoded vislcg_path (we assume that vislcg_path is inside system PATH)
|
diff --git a/porespy/filters/__funcs__.py b/porespy/filters/__funcs__.py
index <HASH>..<HASH> 100644
--- a/porespy/filters/__funcs__.py
+++ b/porespy/filters/__funcs__.py
@@ -1264,8 +1264,8 @@ def trim_disconnected_blobs(im, inlets):
temp = sp.zeros_like(im)
temp[inlets] = True
labels, N = spim.label(im + temp)
- im = im ^ (clear_border(labels=labels) > 0)
- return im
+ im2 = im ^ (clear_border(labels=labels) > 0)
+ return im2
def _get_axial_shifts(ndim=2, include_diagonals=False):
|
changing trim_disconnected_blobs to make a copy of input image
|
diff --git a/satpy/tests/writer_tests/test_cf.py b/satpy/tests/writer_tests/test_cf.py
index <HASH>..<HASH> 100644
--- a/satpy/tests/writer_tests/test_cf.py
+++ b/satpy/tests/writer_tests/test_cf.py
@@ -328,7 +328,6 @@ class TestCFWriter(unittest.TestCase):
scn.save_datasets(filename=filename,
header_attrs=header_attrs,
writer='cf')
- import netCDF4 as nc4
with xr.open_dataset(filename) as f:
self.assertTrue(f.attrs['sensor'] == 'SEVIRI')
self.assertTrue('sensor' in f.attrs.keys())
|
Remove unused import in cf writer tests
|
diff --git a/pypureomapi.py b/pypureomapi.py
index <HASH>..<HASH> 100644
--- a/pypureomapi.py
+++ b/pypureomapi.py
@@ -1090,6 +1090,25 @@ class Omapi(object):
if response.opcode != OMAPI_OP_STATUS:
raise OmapiError("delete failed")
+ def lookup_ip_host(self, mac):
+ """Lookup a host object with with given mac address.
+
+ @type mac: str
+ @raises ValueError:
+ @raises OmapiError:
+ @raises socket.error:
+ """
+ msg = OmapiMessage.open(b"host")
+ msg.obj.append((b"hardware-address", pack_mac(mac)))
+ msg.obj.append((b"hardware-type", struct.pack("!I", 1)))
+ response = self.query_server(msg)
+ if response.opcode != OMAPI_OP_UPDATE:
+ raise OmapiErrorNotFound()
+ try:
+ return unpack_ip(dict(response.obj)[b"ip-address"])
+ except KeyError: # ip-address
+ raise OmapiErrorNotFound()
+
def lookup_ip(self, mac):
"""Look for a lease object with given mac address and return the
assigned ip address.
|
Added function 'lookup_ip_host' to lookup the IP address corresponding to a MAC address in a host entry
|
diff --git a/source/config/albus.php b/source/config/albus.php
index <HASH>..<HASH> 100644
--- a/source/config/albus.php
+++ b/source/config/albus.php
@@ -12,6 +12,7 @@ return [
* Controller associated with albus dashboard (homepage). Use controller alias, not class name.
*/
'defaultController' => '',
+
/*
* List of controller classes associated with their alias to be available for albus. No other
* controllers can be called.
|
Albus routing and HMVC core basemenet.
|
diff --git a/snapshot-webapp/src/test/java/org/duracloud/snapshot/rest/SnapshotResourceTest.java b/snapshot-webapp/src/test/java/org/duracloud/snapshot/rest/SnapshotResourceTest.java
index <HASH>..<HASH> 100644
--- a/snapshot-webapp/src/test/java/org/duracloud/snapshot/rest/SnapshotResourceTest.java
+++ b/snapshot-webapp/src/test/java/org/duracloud/snapshot/rest/SnapshotResourceTest.java
@@ -45,10 +45,10 @@ public class SnapshotResourceTest extends SnapshotTestBase {
private String[] dpnEmailAddresses = {"dpn-email"};
private String duracloudUsername = "duracloud-username";
private String duracloudPassword = "duracloud-password";
- private File workDir = new File(System.getProperty("java.io.tmpdir")
- + "snapshot-work");
- private File contentDirRoot = new File(System.getProperty("java.io.tmpdir")
- + "snapshot-content");
+ private File workDir = new File(System.getProperty("java.io.tmpdir"),
+ "snapshot-work");
+ private File contentDirRoot = new File(System.getProperty("java.io.tmpdir"),
+ "snapshot-content");
private boolean clean = true;
|
Fixes broken unit test (on linux only) and likely resolves write permission detection anomaly.
|
diff --git a/lib/transitions/machine.rb b/lib/transitions/machine.rb
index <HASH>..<HASH> 100644
--- a/lib/transitions/machine.rb
+++ b/lib/transitions/machine.rb
@@ -96,7 +96,7 @@ module Transitions
def include_scopes
@states.each do |state|
- @klass.scope state.name.to_sym, @klass.where(:state => state.name)
+ @klass.scope state.name.to_sym, @klass.where(:state => state.name.to_s)
end
end
end
|
Stringify state name
AR prefixes the state with the table name (i.e. "`traffic_lights`.`state` = `traffic_lights`.`red`") if we pass the name as symbol. We need to pass it as string, so that it works ("`traffic_lights`.`state` = 'red'")
|
diff --git a/internal/service/keyspaces/table.go b/internal/service/keyspaces/table.go
index <HASH>..<HASH> 100644
--- a/internal/service/keyspaces/table.go
+++ b/internal/service/keyspaces/table.go
@@ -34,7 +34,7 @@ func ResourceTable() *schema.Resource {
Timeouts: &schema.ResourceTimeout{
Create: schema.DefaultTimeout(10 * time.Minute),
- Update: schema.DefaultTimeout(10 * time.Minute),
+ Update: schema.DefaultTimeout(20 * time.Minute),
Delete: schema.DefaultTimeout(10 * time.Minute),
},
@@ -656,6 +656,7 @@ func waitTableUpdated(ctx context.Context, conn *keyspaces.Keyspaces, keyspaceNa
Target: []string{keyspaces.TableStatusActive},
Refresh: statusTable(ctx, conn, keyspaceName, tableName),
Timeout: timeout,
+ Delay: 10 * time.Second,
}
outputRaw, err := stateConf.WaitForStateContext(ctx)
|
r/aws_keyspaces_table: Add a <I>s delay before polling for status changes during Update.
|
diff --git a/models/LoginForm.php b/models/LoginForm.php
index <HASH>..<HASH> 100644
--- a/models/LoginForm.php
+++ b/models/LoginForm.php
@@ -23,8 +23,8 @@ class LoginForm extends \yii\base\Model
public function attributeLabels()
{
return [
- 'email' => 'E-Mail',
- 'password' => 'Passwort',
+ 'email' => \admin\Module::t('model_loginform_email_label'),
+ 'password' => \admin\Module::t('model_loginform_password_label'),
];
}
@@ -33,7 +33,7 @@ class LoginForm extends \yii\base\Model
if (!$this->hasErrors()) {
$user = $this->getUser();
if (!$user || !$user->validatePassword($this->password)) {
- $this->addError($attribute, 'Falscher Benutzer oder Passwort.');
+ $this->addError($attribute, \admin\Module::t('model_loginform_wrong_user_or_password'));
}
}
}
|
Adding new translations and changing the structure to group translations by version
|
diff --git a/app/View.php b/app/View.php
index <HASH>..<HASH> 100644
--- a/app/View.php
+++ b/app/View.php
@@ -28,6 +28,7 @@ use function extract;
use function implode;
use function is_file;
use function ob_end_clean;
+use function ob_get_level;
use function ob_start;
use function sha1;
@@ -191,7 +192,9 @@ class View
return ob_get_clean();
} catch (Throwable $ex) {
- ob_end_clean();
+ while (ob_get_level() > 0) {
+ ob_end_clean();
+ }
throw $ex;
}
}
|
Fix: errors in nested views not handled correctly
|
diff --git a/lib/files.js b/lib/files.js
index <HASH>..<HASH> 100644
--- a/lib/files.js
+++ b/lib/files.js
@@ -314,12 +314,21 @@ module.exports = {
// normally granted to all users in groups with the
// `edit` or `admin` permission.
+ // If you are allowing for public image uploading into
+ // the media library (perhaps using apostrophe-moderator),
+ // IE9 and below do not react properly to the json content
+ // type. Post images to '/apos/upload-files?html=1' and
+ // the server will respond with text/html instead.
+
self.app.post('/apos/upload-files', function(req, res) {
return self.acceptFiles(req, req.files.files, function(err, files) {
if (err) {
console.error(err);
return res.send({ files: [], status: 'err' });
}
+ if(req.query.html) {
+ res.setHeader('Content-Type', 'text/html');
+ }
return res.send({ files: files, status: 'ok' });
});
});
|
added ?html=1 query option to apos/upload-files to allow for IE9 compatibility when allowing public image uploads
|
diff --git a/app/javascript/packs/fluent_log.js b/app/javascript/packs/fluent_log.js
index <HASH>..<HASH> 100644
--- a/app/javascript/packs/fluent_log.js
+++ b/app/javascript/packs/fluent_log.js
@@ -10,7 +10,7 @@ $(document).ready(()=> {
"processing": false
},
- compiled: function(){
+ mounted: function(){
this.fetchLogs();
var self = this;
|
Use mounted instead of compiled
Because compiled is removed.
|
diff --git a/pkg/controller/service/service_controller.go b/pkg/controller/service/service_controller.go
index <HASH>..<HASH> 100644
--- a/pkg/controller/service/service_controller.go
+++ b/pkg/controller/service/service_controller.go
@@ -107,6 +107,7 @@ func New(
broadcaster := record.NewBroadcaster()
broadcaster.StartRecordingToSink(&v1core.EventSinkImpl{Interface: v1core.New(kubeClient.Core().RESTClient()).Events("")})
recorder := broadcaster.NewRecorder(scheme.Scheme, v1.EventSource{Component: "service-controller"})
+ broadcaster.StartLogging(glog.Infof)
if kubeClient != nil && kubeClient.Core().RESTClient().GetRateLimiter() != nil {
metrics.RegisterMetricAndTrackRateLimiterUsage("service_controller", kubeClient.Core().RESTClient().GetRateLimiter())
|
Enable event logging in the service controller
|
diff --git a/Controller/Payment/Verify.php b/Controller/Payment/Verify.php
index <HASH>..<HASH> 100755
--- a/Controller/Payment/Verify.php
+++ b/Controller/Payment/Verify.php
@@ -158,6 +158,10 @@ class Verify extends AbstractAction {
// Debug info
$this->watchdog->bark($response);
+ if (isset($response['responseCode']) && (int) $response['responseCode'] >= 40000) {
+ throw new LocalizedException(__('There has been an error processing your transaction.'));
+ }
+
// If it's an alternative payment
if (isset($response['chargeMode']) && (int) $response['chargeMode'] == 3) {
if (isset($response['responseCode']) && (int) $response['responseCode'] == 10000 || (int) $response['responseCode'] == 10100) {
|
Response code handling
Improved the handling of blacklisted cards response.
|
diff --git a/code/gridfield/GridFieldImporter.php b/code/gridfield/GridFieldImporter.php
index <HASH>..<HASH> 100644
--- a/code/gridfield/GridFieldImporter.php
+++ b/code/gridfield/GridFieldImporter.php
@@ -29,9 +29,10 @@ class GridFieldImporter implements GridField_HTMLProvider, GridField_URLHandler
/**
* Set the bulk loader for this importer
- * @param BulkLoader
+ * @param BetterBulkLoader $loader
+ * @return GridFieldImporter
*/
- public function setLoader(BulkLoader $loader) {
+ public function setLoader(BetterBulkLoader $loader) {
$this->loader = $loader;
return $this;
@@ -39,7 +40,7 @@ class GridFieldImporter implements GridField_HTMLProvider, GridField_URLHandler
/**
* Get the BulkLoader
- * @return BulkLoader
+ * @return BetterBulkLoader
*/
public function getLoader(GridField $gridField) {
if(!$this->loader){
@@ -67,9 +68,9 @@ class GridFieldImporter implements GridField_HTMLProvider, GridField_URLHandler
}
/**
- * @param boolean $canclear
+ * @param boolean $canClearData
*/
- public function setCanClearData($canclear = true) {
+ public function setCanClearData($canClearData = true) {
$this->canClearData = $canClearData;
}
|
FIX for #<I>: Ensuring documentation and setters are utilizing correct type. Also minor fix to setter variable name.
|
diff --git a/src/FormElement/AbstractFormElement.php b/src/FormElement/AbstractFormElement.php
index <HASH>..<HASH> 100644
--- a/src/FormElement/AbstractFormElement.php
+++ b/src/FormElement/AbstractFormElement.php
@@ -177,7 +177,7 @@ abstract class AbstractFormElement
// Build input validator chain for element
$this->attachValidators($input, $element);
$this->attachValidatorsFromDataAttribute($input, $element);
- $this->attachFilters($input, $element->getAttribute('data-filters'));
+ $this->attachFilters($input, $element);
// Can't be empty if it has a required attribute
if ($element->hasAttribute('required')) {
@@ -217,8 +217,9 @@ abstract class AbstractFormElement
}
}
- public function attachFilters(InputInterface $input, $filters)
+ public function attachFilters(InputInterface $input, DOMElement $element)
{
+ $filters = $element->getAttribute('data-filters');
$filters = explode(',', $filters);
foreach ($filters as $filter) {
// TODO: Needs to fixed when zend-inputfilter 3 is released.
|
Make attach filters function consistent with other attach functions
|
diff --git a/tests/WidgetTest/DbTest.php b/tests/WidgetTest/DbTest.php
index <HASH>..<HASH> 100644
--- a/tests/WidgetTest/DbTest.php
+++ b/tests/WidgetTest/DbTest.php
@@ -282,5 +282,15 @@ class DbTest extends TestCase
$this->assertEquals("SELECT * FROM users u WHERE id = ? AND group_id IN (?, ?)", $query->getSQL());
$this->assertEquals('1', $user->id);
+
+ // Order
+ $query = $this->db('users')->orderBy('id', 'ASC');
+ $user = $query->find();
+
+ $this->assertEquals("SELECT * FROM users u ORDER BY id ASC", $query->getSQL());
+ $this->assertEquals("1", $user->id);
+
+ // addOrder
+
}
}
\ No newline at end of file
|
added test for order by clause, ref #<I>
|
diff --git a/sonar-plugin-api/src/main/java/org/sonar/api/server/ws/WebService.java b/sonar-plugin-api/src/main/java/org/sonar/api/server/ws/WebService.java
index <HASH>..<HASH> 100644
--- a/sonar-plugin-api/src/main/java/org/sonar/api/server/ws/WebService.java
+++ b/sonar-plugin-api/src/main/java/org/sonar/api/server/ws/WebService.java
@@ -353,13 +353,11 @@ public interface WebService extends Definable<WebService.Context> {
createParam(Param.PAGE)
.setDescription(PAGE_PARAM_DESCRIPTION)
.setExampleValue("42")
- .setDeprecatedKey("pageIndex", "5.2")
.setDefaultValue("1");
createParam(Param.PAGE_SIZE)
.setDescription("Page size. Must be greater than 0.")
.setExampleValue("20")
- .setDeprecatedKey("pageSize", "5.2")
.setDefaultValue(String.valueOf(defaultPageSize));
return this;
}
|
SONAR-<I> remove deprecated 'pageIndex' and 'pageSize' params from web services
|
diff --git a/stanza/server/client.py b/stanza/server/client.py
index <HASH>..<HASH> 100644
--- a/stanza/server/client.py
+++ b/stanza/server/client.py
@@ -615,6 +615,8 @@ class CoreNLPClient(RobustService):
timeout=(self.timeout*2)/1000,
)
r.raise_for_status()
+ if r.encoding is None:
+ r.encoding = "utf-8"
return json.loads(r.text)
except requests.HTTPError as e:
if r.text.startswith("Timeout"):
|
If the response encoding isn't set, assume utf-8. Helps on Windows
|
diff --git a/server/engine.js b/server/engine.js
index <HASH>..<HASH> 100644
--- a/server/engine.js
+++ b/server/engine.js
@@ -1,8 +1,9 @@
'use strict';
-var torrentStream = require('torrent-stream');
+var torrentStream = require('torrent-stream'),
+ _ = require('lodash');
module.exports = function (magnetUri, opts) {
- var engine = torrentStream(magnetUri, opts);
+ var engine = torrentStream(magnetUri, _.clone(opts, true));
engine.once('verifying', function () {
console.log('verifying ' + magnetUri.infoHash);
@@ -11,7 +12,7 @@ module.exports = function (magnetUri, opts) {
});
});
- engine.on('ready', function () {
+ engine.once('ready', function () {
console.log('ready ' + magnetUri.infoHash);
//engine.swarm.pause();
});
diff --git a/server/store.js b/server/store.js
index <HASH>..<HASH> 100644
--- a/server/store.js
+++ b/server/store.js
@@ -48,6 +48,8 @@ var store = {
return infoHash;
}
+ console.log('adding ' + infoHash);
+
var torrent = engine(magnetUri, options);
socket.register(infoHash, torrent);
torrents[infoHash] = torrent;
|
clone the options for each torrent
|
diff --git a/lib/server/request.rb b/lib/server/request.rb
index <HASH>..<HASH> 100644
--- a/lib/server/request.rb
+++ b/lib/server/request.rb
@@ -14,7 +14,7 @@ module Server
end
def params
- return {} unless uri
+ query = URI(uri).query || ''
@params ||= CGI::parse(URI(uri).query)
end
|
fix param access when there are no params in uri
|
diff --git a/lib/quickbooks/service/reports.rb b/lib/quickbooks/service/reports.rb
index <HASH>..<HASH> 100644
--- a/lib/quickbooks/service/reports.rb
+++ b/lib/quickbooks/service/reports.rb
@@ -12,8 +12,9 @@ module Quickbooks
end
options_string = options_string[0..-2]
options_string.gsub!(/\s/,"%20")
- # finalURL = "#{url_for_resource(model::REST_RESOURCE)}/#{report_name}#{options_string}"
- return "#{url_for_base}/reports/#{which_report}?date_macro=#{URI.encode_www_form_component(date_macro)}&#{options_string}"
+ finalURL = "#{url_for_base}/reports/#{which_report}?date_macro=#{URI.encode_www_form_component(date_macro)}&#{options_string}"
+ puts finalURL
+ return finalURL
end
end
|
logging of URL for debugging
|
diff --git a/oa-enterprise/lib/omniauth/strategies/ldap/adaptor.rb b/oa-enterprise/lib/omniauth/strategies/ldap/adaptor.rb
index <HASH>..<HASH> 100644
--- a/oa-enterprise/lib/omniauth/strategies/ldap/adaptor.rb
+++ b/oa-enterprise/lib/omniauth/strategies/ldap/adaptor.rb
@@ -55,7 +55,7 @@ module OmniAuth
config = {
:host => host,
- :eport => port,
+ :port => port,
}
config[:encryption] = {:method => method} if method
|
fix typo which broke LDAP authentication
|
diff --git a/lib/controller/controller.rb b/lib/controller/controller.rb
index <HASH>..<HASH> 100644
--- a/lib/controller/controller.rb
+++ b/lib/controller/controller.rb
@@ -126,7 +126,7 @@ module Ava
def register_client(addr, key)
return "Your IP is not allowed: #{addr}" unless validate_ip(addr)
- return { status: 401, error: ArgumentError.new('Invalid secret key.') } unless @key == key
+ return { status: 401, error: ArgumentError.new('Invalid secret key.') } unless self.key == key
@connections[addr] = {
key: Digest::SHA1.hexdigest("#{addr}|#{@key}"),
iv: @cipher.random_iv,
|
Removed instance variable call and replaced with correct method.
|
diff --git a/lib/wavefile.rb b/lib/wavefile.rb
index <HASH>..<HASH> 100644
--- a/lib/wavefile.rb
+++ b/lib/wavefile.rb
@@ -7,7 +7,7 @@ require 'wavefile/unvalidated_format'
require 'wavefile/writer'
module WaveFile
- VERSION = "0.8.0"
+ VERSION = "0.8.1"
WAVEFILE_FORMAT_CODE = "WAVE" # :nodoc:
FORMAT_CODES = {:pcm => 1, :float => 3, :extensible => 65534} # :nodoc:
|
Bumping version from <I> -> <I>
|
diff --git a/basepath_test.go b/basepath_test.go
index <HASH>..<HASH> 100644
--- a/basepath_test.go
+++ b/basepath_test.go
@@ -119,7 +119,7 @@ func TestNestedBasePaths(t *testing.T) {
}
for _, s := range specs {
- if actualPath, err := s.BaseFs.(*BasePathFs).RealPath(s.FileName); err != nil {
+ if actualPath, err := s.BaseFs.(*BasePathFs).fullPath(s.FileName); err != nil {
t.Errorf("Got error %s", err.Error())
} else if actualPath != s.ExpectedPath {
t.Errorf("Expected \n%s got \n%s", s.ExpectedPath, actualPath)
|
Closes spf<I>/afero#<I>
Amendment to previous commit, fixed the related test
|
diff --git a/js/reveal.js b/js/reveal.js
index <HASH>..<HASH> 100644
--- a/js/reveal.js
+++ b/js/reveal.js
@@ -1292,7 +1292,7 @@
if( value === 'null' ) return null;
else if( value === 'true' ) return true;
else if( value === 'false' ) return false;
- else if( value.match( /^[\d\.]+$/ ) ) return parseFloat( value );
+ else if( value.match( /^-?[\d\.]+$/ ) ) return parseFloat( value );
}
return value;
|
support negative values in query config overrides
|
diff --git a/src/Driver/Http2Driver.php b/src/Driver/Http2Driver.php
index <HASH>..<HASH> 100644
--- a/src/Driver/Http2Driver.php
+++ b/src/Driver/Http2Driver.php
@@ -959,20 +959,8 @@ final class Http2Driver implements HttpDriver
$error = \unpack("N", $buffer)[1];
- if (isset($this->bodyEmitters[$id], $this->trailerDeferreds[$id])) {
- $exception = new ClientException("Client ended stream", self::STREAM_CLOSED);
-
- $emitter = $this->bodyEmitters[$id];
- $deferred = $this->trailerDeferreds[$id];
-
- unset($this->bodyEmitters[$id], $this->trailerDeferreds[$id]);
-
- $emitter->fail($exception);
- $deferred->fail($exception);
- }
-
if (isset($this->streams[$id])) {
- $this->releaseStream($id);
+ $this->releaseStream($id, new ClientException("Client ended stream", $error));
}
$buffer = \substr($buffer, 4);
|
Send exception to releaseStream on RST_STREAM frame
|
diff --git a/core/src/main/java/de/bwaldvogel/mongo/wire/MongoWireEncoder.java b/core/src/main/java/de/bwaldvogel/mongo/wire/MongoWireEncoder.java
index <HASH>..<HASH> 100644
--- a/core/src/main/java/de/bwaldvogel/mongo/wire/MongoWireEncoder.java
+++ b/core/src/main/java/de/bwaldvogel/mongo/wire/MongoWireEncoder.java
@@ -17,8 +17,7 @@ public class MongoWireEncoder extends MessageToByteEncoder<MongoReply> {
private static final Logger log = LoggerFactory.getLogger(MongoWireEncoder.class);
@Override
- protected void encode(ChannelHandlerContext ctx, MongoReply reply, ByteBuf buf) throws Exception {
-
+ protected void encode(ChannelHandlerContext ctx, MongoReply reply, ByteBuf buf) {
buf.writeIntLE(0); // write length later
buf.writeIntLE(reply.getHeader().getRequestID());
|
Cleanup MongoWireEncoder
|
diff --git a/lib/jobs/index.js b/lib/jobs/index.js
index <HASH>..<HASH> 100644
--- a/lib/jobs/index.js
+++ b/lib/jobs/index.js
@@ -8,7 +8,6 @@ module.exports = {
artifactsDestroy: require('./artifactsDestroy'),
artifactsGet: require('./artifactsGet'),
artifactsList: require('./artifactsList'),
- artifactsShare: require('./artifactsShare'),
clone: require('./clone'),
create: require('./create'),
destroy: require('./destroy'),
|
remove artifactsShare method from docs for this release
|
diff --git a/media/boom/js/boom.assets.js b/media/boom/js/boom.assets.js
index <HASH>..<HASH> 100755
--- a/media/boom/js/boom.assets.js
+++ b/media/boom/js/boom.assets.js
@@ -44,19 +44,11 @@ $.extend($.boom.assets, {
height: 500,
title: 'Select an asset',
cache: false,
- buttons: {
- '✕': function() {
- cleanup();
- ( opts.deferred ) && opts.deferred.reject();
- return false;
- },
- '✔': function() {
- var asset_id = browser.browser_asset( 'get_asset' );
- cleanup();
- ( opts.deferred ) && opts.deferred.resolve();
- complete.resolve( asset_id );
- return false;
- }
+ callback: function() {
+ var asset_id = browser.browser_asset( 'get_asset' );
+ cleanup();
+ complete.resolve( asset_id );
+ return false;
},
open: function(){
$.boom.log( 'dialog open' );
|
remove custom okay/cancel buttons from asset manager dialog
|
diff --git a/gromacs/fileformats/xvg.py b/gromacs/fileformats/xvg.py
index <HASH>..<HASH> 100644
--- a/gromacs/fileformats/xvg.py
+++ b/gromacs/fileformats/xvg.py
@@ -527,6 +527,10 @@ class XVG(utilities.FileUtils):
finally:
del rows # try to clean up as well as possible as it can be massively big
+ def to_df(self):
+ import pandas as _pd
+ return _pd.DataFrame(self.array.T, columns=["X",]+self.names, dtype=float)
+
def set(self, a):
"""Set the *array* data from *a* (i.e. completely replace).
|
Convert the xvg file to a Pandas DataFrame
- unclear if this is desired, Oli may not want to add dependancies such as pandas
|
diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100644
--- a/setup.py
+++ b/setup.py
@@ -262,7 +262,7 @@ def get_version_info():
# If this is a release or another kind of source distribution of PyCBC
except:
- version = '1.6.10'
+ version = '1.6.11'
release = 'True'
date = hash = branch = tag = author = committer = status = builder = build_date = ''
|
set to <I> to test deployment
|
diff --git a/cas-server-core/src/test/java/org/jasig/cas/authentication/FileTrustStoreSslSocketFactoryTests.java b/cas-server-core/src/test/java/org/jasig/cas/authentication/FileTrustStoreSslSocketFactoryTests.java
index <HASH>..<HASH> 100644
--- a/cas-server-core/src/test/java/org/jasig/cas/authentication/FileTrustStoreSslSocketFactoryTests.java
+++ b/cas-server-core/src/test/java/org/jasig/cas/authentication/FileTrustStoreSslSocketFactoryTests.java
@@ -48,7 +48,7 @@ public class FileTrustStoreSslSocketFactoryTests {
final ClassPathResource resource = new ClassPathResource("truststore.jks");
final FileTrustStoreSslSocketFactory factory = new FileTrustStoreSslSocketFactory(resource.getFile(), "changeit");
final SimpleHttpClient client = new SimpleHttpClient(factory);
- assertTrue(client.isValidEndPoint("https://www.cacert.org"));
+ assertTrue(client.isValidEndPoint("https://test.scaldingspoon.org/idp/shibboleth"));
}
|
Issue <I>: revert wrong change on cert tests
|
diff --git a/setup.py b/setup.py
index <HASH>..<HASH> 100644
--- a/setup.py
+++ b/setup.py
@@ -1,7 +1,7 @@
#!/usr/bin/env python
import os
-from setuptools import setup
+from distutils.core import setup
from neo4jrestclient import constants
|
Switched back to distutils so it will actually be installable ;).
|
diff --git a/pig/src/main/java/com/twitter/elephantbird/pig/util/ThriftToPig.java b/pig/src/main/java/com/twitter/elephantbird/pig/util/ThriftToPig.java
index <HASH>..<HASH> 100644
--- a/pig/src/main/java/com/twitter/elephantbird/pig/util/ThriftToPig.java
+++ b/pig/src/main/java/com/twitter/elephantbird/pig/util/ThriftToPig.java
@@ -91,7 +91,7 @@ public class ThriftToPig<M extends TBase<?, ?>> {
public static void setConversionProperties(Configuration conf) {
if (conf != null) {
useEnumId = conf.getBoolean(USE_ENUM_ID_CONF_KEY, false);
- LOG.info("useEnumId is set to " + useEnumId);
+ LOG.debug("useEnumId is set to " + useEnumId);
}
}
|
Change the log information for USE_ENUM_ID_CONF_KEY to debug level.
|
diff --git a/src/js/bootstrap-datetimepicker.js b/src/js/bootstrap-datetimepicker.js
index <HASH>..<HASH> 100644
--- a/src/js/bootstrap-datetimepicker.js
+++ b/src/js/bootstrap-datetimepicker.js
@@ -110,7 +110,7 @@ THE SOFTWARE.
}
}
}
- picker.use24hours = (picker.format.toLowerCase().indexOf('a') < 1 && picker.format.indexOf('h') < 1);
+ picker.use24hours = (picker.format.toLowerCase().indexOf('a') < 0 && picker.format.indexOf('h') < 0);
if (picker.component) {
icon = picker.component.find('span');
|
Fixed comparison
We're looking for cases where 'a', 'A' and 'h' are not in the format string. They can be in first position so need to check for 'not found', i.e. `<0` or `-1`.
|
diff --git a/cmd/lncli/commands.go b/cmd/lncli/commands.go
index <HASH>..<HASH> 100644
--- a/cmd/lncli/commands.go
+++ b/cmd/lncli/commands.go
@@ -1014,6 +1014,7 @@ func sendPayment(ctx *cli.Context) error {
if ctx.IsSet("pay_req") {
req = &lnrpc.SendRequest{
PaymentRequest: ctx.String("pay_req"),
+ Amt: ctx.Int64("amt"),
}
} else {
args := ctx.Args()
@@ -1138,6 +1139,11 @@ var payInvoiceCommand = cli.Command{
Name: "pay_req",
Usage: "a zpay32 encoded payment request to fulfill",
},
+ cli.Int64Flag{
+ Name: "amt",
+ Usage: "(optional) number of satoshis to fulfill the " +
+ "invoice",
+ },
},
Action: actionDecorator(payInvoice),
}
@@ -1158,6 +1164,7 @@ func payInvoice(ctx *cli.Context) error {
req := &lnrpc.SendRequest{
PaymentRequest: payReq,
+ Amt: ctx.Int64("amt"),
}
return sendPaymentRequest(ctx, req)
|
lncli: optionally include the amount in the payment request
|
diff --git a/enabler/src/com/openxc/enabler/BootupReceiver.java b/enabler/src/com/openxc/enabler/BootupReceiver.java
index <HASH>..<HASH> 100644
--- a/enabler/src/com/openxc/enabler/BootupReceiver.java
+++ b/enabler/src/com/openxc/enabler/BootupReceiver.java
@@ -15,7 +15,7 @@ import android.util.Log;
* management.
*/
public class BootupReceiver extends BroadcastReceiver {
- private final static String TAG = "BootupReceiver";
+ private final static String TAG = BootupReceiver.class.getSimpleName();
// TODO what about when the device is already started? need an app to hit?
// or do we rely on it being started by the bind call? might get duplicate
|
Grab log TAG without a hard coded string.
|
diff --git a/src/core/text/Text.js b/src/core/text/Text.js
index <HASH>..<HASH> 100644
--- a/src/core/text/Text.js
+++ b/src/core/text/Text.js
@@ -32,10 +32,11 @@ export default class Text extends Sprite
/**
* @param {string} text - The string that you would like the text to display
* @param {object|PIXI.TextStyle} [style] - The style parameters
+ * @param {HTMLCanvasElement} [canvas] - The canvas element for drawing text
*/
- constructor(text, style)
+ constructor(text, style, canvas)
{
- const canvas = document.createElement('canvas');
+ canvas = canvas || document.createElement('canvas');
canvas.width = 3;
canvas.height = 3;
|
The canvas could be passed into Text
This feature could help users to share canvas among two or more Text objects ( like Graphics._SPRITE_TEXTURE in Graphics).
In the game ,normally we need rebuild stage/scene when stage/scene changed , If Text supports passing canvas , we could avoid create and destroy HTMLCanvasElement often when game running.
e.g. create a canvas-pool cache some canvas for Text.
|
diff --git a/lib/Cake/Test/Case/Network/Email/CakeEmailTest.php b/lib/Cake/Test/Case/Network/Email/CakeEmailTest.php
index <HASH>..<HASH> 100644
--- a/lib/Cake/Test/Case/Network/Email/CakeEmailTest.php
+++ b/lib/Cake/Test/Case/Network/Email/CakeEmailTest.php
@@ -848,6 +848,7 @@ class CakeEmailTest extends CakeTestCase {
* @return void
*/
public function testSendRenderWithVarsJapanese() {
+ $this->skipIf(!function_exists('mb_convert_encoding'));
$this->CakeEmail->reset();
$this->CakeEmail->transport('debug');
|
Added skip if mbstring not available
|
diff --git a/Classes/Command/HelpCommandController.php b/Classes/Command/HelpCommandController.php
index <HASH>..<HASH> 100644
--- a/Classes/Command/HelpCommandController.php
+++ b/Classes/Command/HelpCommandController.php
@@ -30,13 +30,14 @@ namespace Helhum\Typo3Console\Command;
use Helhum\Typo3Console\Core\Booting\RunLevel;
use Helhum\Typo3Console\Core\ConsoleBootstrap;
+use Helhum\Typo3Console\Mvc\Controller\CommandController;
/**
* A Command Controller which provides help for available commands
*
* @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License, version 3 or later
*/
-class HelpCommandController extends \TYPO3\CMS\Extbase\Mvc\Controller\CommandController {
+class HelpCommandController extends CommandController {
/**
* @var \Helhum\Typo3Console\Mvc\Cli\CommandManager
|
[BUGFIX] Fix help command for <I> TYPO3 branch
|
diff --git a/config/database.php b/config/database.php
index <HASH>..<HASH> 100644
--- a/config/database.php
+++ b/config/database.php
@@ -64,15 +64,6 @@ $configuration["pluralizeTableName"] = true;
$configuration["tableNameStyle"] = BaseModel::TBL_NAME_CAMEL_LCFIRST;
/*
- * Model loader
- *
- * Available options are:
- * - PDO (if subcomponent database-pdo is installed)
- * - Illuminate (if subcomponent database-illuminate is installed)
- */
-$configuration["loader"] = "PHP";
-
-/*
* Model class namespace
*
* The namespace in which the Model classes are defined.
|
currently only one loader, removing config option
|
diff --git a/trailblazer/mip/config.py b/trailblazer/mip/config.py
index <HASH>..<HASH> 100644
--- a/trailblazer/mip/config.py
+++ b/trailblazer/mip/config.py
@@ -29,10 +29,10 @@ class SampleSchema(Schema):
)
expected_coverage = fields.Float()
capture_kit = fields.Str(
- validate=validate.OneOf(choices=['Agilent_SureSelectCRE.V1',
- 'Agilent_SureSelect.V5',
- 'Agilent_SureSelectFocusedExome.V1']),
- default='Agilent_SureSelectCRE.V1'
+ validate=validate.OneOf(choices=['agilent_sureselect_cre.v1',
+ 'agilent_sureselect.v5',
+ 'agilent_sureselect_focusedexome.v1']),
+ default='agilent_sureselect_cre.v1',
)
|
update to MIP 5 capture kit keys
|
diff --git a/go/sqltypes/value_test.go b/go/sqltypes/value_test.go
index <HASH>..<HASH> 100644
--- a/go/sqltypes/value_test.go
+++ b/go/sqltypes/value_test.go
@@ -578,14 +578,14 @@ func TestParseNumbers(t *testing.T) {
t.Error(err)
}
if uval != 1 {
- t.Errorf("v.ParseInt64 = %d, want 1", uval)
+ t.Errorf("v.ParseUint64 = %d, want 1", uval)
}
fval, err := v.ParseFloat64()
if err != nil {
t.Error(err)
}
if fval != 1 {
- t.Errorf("v.ParseInt64 = %f, want 1", fval)
+ t.Errorf("v.ParseFloat64 = %f, want 1", fval)
}
}
|
fix method names in Errorf calls
|
diff --git a/sharding-core/src/main/java/io/shardingsphere/core/parsing/parser/dialect/sqlserver/sql/SQLServerSelectParser.java b/sharding-core/src/main/java/io/shardingsphere/core/parsing/parser/dialect/sqlserver/sql/SQLServerSelectParser.java
index <HASH>..<HASH> 100755
--- a/sharding-core/src/main/java/io/shardingsphere/core/parsing/parser/dialect/sqlserver/sql/SQLServerSelectParser.java
+++ b/sharding-core/src/main/java/io/shardingsphere/core/parsing/parser/dialect/sqlserver/sql/SQLServerSelectParser.java
@@ -45,7 +45,6 @@ public final class SQLServerSelectParser extends AbstractSelectParser {
@Override
protected void parseInternal(final SelectStatement selectStatement) {
- parseDistinct();
parseTop(selectStatement);
parseSelectList(selectStatement, getItems());
parseFrom(selectStatement);
|
delete parseDistinct();
|
diff --git a/lib/discordrb/bot.rb b/lib/discordrb/bot.rb
index <HASH>..<HASH> 100644
--- a/lib/discordrb/bot.rb
+++ b/lib/discordrb/bot.rb
@@ -517,6 +517,11 @@ module Discordrb
handle_dispatch(type, data)
end
+ # Raises a heartbeat event. Called by the gateway connection handler used internally.
+ def raise_heartbeat_event(event)
+ raise_event(event)
+ end
+
private
# Throws a useful exception if there's currently no gateway connection
diff --git a/lib/discordrb/gateway.rb b/lib/discordrb/gateway.rb
index <HASH>..<HASH> 100644
--- a/lib/discordrb/gateway.rb
+++ b/lib/discordrb/gateway.rb
@@ -353,6 +353,7 @@ module Discordrb
# suspended (e.g. after op7)
if (@session && !@session.suspended?) || !@session
sleep @heartbeat_interval
+ @bot.raise_heartbeat_event(Discordrb::Events::HeartbeatEvent.new(self))
heartbeat
else
sleep 1
|
Reintroduces heartbeat events that were lost in the gateway update
|
diff --git a/scribble-jcr/src/main/java/io/inkstand/scribble/jcr/rules/RemoteContentRepository.java b/scribble-jcr/src/main/java/io/inkstand/scribble/jcr/rules/RemoteContentRepository.java
index <HASH>..<HASH> 100644
--- a/scribble-jcr/src/main/java/io/inkstand/scribble/jcr/rules/RemoteContentRepository.java
+++ b/scribble-jcr/src/main/java/io/inkstand/scribble/jcr/rules/RemoteContentRepository.java
@@ -262,7 +262,7 @@ public class RemoteContentRepository extends ContentRepository {
return contextRoot;
}
- private class ArquillianLaunchVariableResolver implements XPathVariableResolver {
+ private static class ArquillianLaunchVariableResolver implements XPathVariableResolver {
private final String qualifier;
|
fixed sonar issues (changed to static class)
|
diff --git a/nephele/nephele-server/src/main/java/eu/stratosphere/nephele/taskmanager/bytebuffered/OutgoingConnection.java b/nephele/nephele-server/src/main/java/eu/stratosphere/nephele/taskmanager/bytebuffered/OutgoingConnection.java
index <HASH>..<HASH> 100644
--- a/nephele/nephele-server/src/main/java/eu/stratosphere/nephele/taskmanager/bytebuffered/OutgoingConnection.java
+++ b/nephele/nephele-server/src/main/java/eu/stratosphere/nephele/taskmanager/bytebuffered/OutgoingConnection.java
@@ -493,10 +493,10 @@ public class OutgoingConnection {
}
}
}
-
+
// Recycle buffer outside of queuedEnvelopes monitor, otherwise dead locks might occur
final Iterator<Buffer> it = buffersToRecycle.iterator();
- while(it.hasNext()) {
+ while (it.hasNext()) {
it.next().recycleBuffer();
}
}
|
Corrected code style of OutgoingConnection.java
|
diff --git a/lib/index.js b/lib/index.js
index <HASH>..<HASH> 100644
--- a/lib/index.js
+++ b/lib/index.js
@@ -44,7 +44,7 @@ function initializer(key, base_url, options) {
}
function parseResponse(err, response, body){
- let data;
+ var data;
if (!body) {
data = err;
} else {
@@ -67,7 +67,7 @@ function parseResponse(err, response, body){
err = new Error(err);
err.code = response.statusCode;
}
- return {err, response, data};
+ return {err: err, response: response, data: data};
}
initializer.prototype._request = function (method, path, params, body, callback){
@@ -96,13 +96,13 @@ initializer.prototype._request = function (method, path, params, body, callback)
//Initiate HTTP request
return callback
? request(options, function(err, response, body) {
- let parsed = parseResponse(err, response, body)
+ var parsed = parseResponse(err, response, body)
return callback(parsed.err, parsed.data, parsed.response)
})
: new Promise(function(resolve, reject) {
request(options, function(err, response, body) {
- let parsed = parseResponse(err, response, body)
+ var parsed = parseResponse(err, response, body)
return parsed.err
? reject(parsed.err)
|
Removed some ES6 syntax
- Follows style of other code
- Plus it was making the parser upset for the tests
|
Subsets and Splits
No community queries yet
The top public SQL queries from the community will appear here once available.
diff --git a/resizer.go b/resizer.go
index <HASH>..<HASH> 100644
--- a/resizer.go
+++ b/resizer.go
@@ -39,8 +39,8 @@ func resizer(buf []byte, o Options) ([]byte, error) {
return nil, err
}
- // If JPEG image, retrieve the buffer
- if rotated && imageType == JPEG && !o.NoAutoRotate {
+ // If JPEG or HEIF image, retrieve the buffer
+ if rotated && (imageType == JPEG || imageType == HEIF) && !o.NoAutoRotate {
buf, err = getImageBuffer(image)
if err != nil {
return nil, err
|
Supporting auto rotate for HEIF/HEIC images.
|